#!/usr/bin/env node
"use strict";

var _chalk = _interopRequireDefault(require("chalk"));

var _child_process = require("child_process");

var _inquirer = _interopRequireDefault(require("inquirer"));

var _os = require("os");

var _path = require("path");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const EMULATOR_PATH = (0, _path.normalize)((0, _path.join)(process.env.ANDROID_HOME, "/emulator/emulator"));

function getEmulators() {
  const emulators = (0, _child_process.execFileSync)(EMULATOR_PATH, ["-list-avds"], {
    encoding: "utf8"
  }).replace(/\n$/, "").split("\n");
  return emulators.filter(Boolean);
}

async function main() {
  const emulators = getEmulators();

  if (emulators.length === 0) {
    console.log(_chalk.default.red("No emulators found"));
    process.exit(1);
  }

  const questions = [{
    type: "list",
    name: "emulator",
    message: "Which emulator do you want to start?",
    choices: emulators
  }];
  const answers = await _inquirer.default.prompt(questions);
  const cleanAnswers = answers.emulator.replace(/\n|\r|\W/g, "");
  console.log(_chalk.default.green("====================================="));
  console.log(_chalk.default.green(`Emulator ${cleanAnswers} is launched`));
  console.log(_chalk.default.green("====================================="));
  const options = {};

  if ((0, _os.platform)() === "win32") {
    options.shell = true;
  }

  const runOnEmulator = (0, _child_process.spawnSync)(EMULATOR_PATH, ["-avd", answers.emulator], options);
  process.exit(0);
}

main();